@@ -1,6 +1,5 @@
-from setux.logger import debug, error, exception, info
+from setux.logger import error
 from setux.util import rm_ansi_codes
-
 from setux.core.package import Packager
 
 
