@@ -1,5 +1,4 @@
-from setux.logger import debug, error, exception, info
-
+from setux.logger import error
 from setux.core.package import Packager
 
 
