@@ -1,8 +1,10 @@
-from setux.logger import debug, error, exception, info
-
+from setux.logger import debug, error
 from setux.core.package import Packager
 
 
+# pylint: disable=expression-not-assigned
+
+
 class Pacman(Packager):
 
     def do_init(self):
