@@ -33,7 +33,7 @@ class Local(Target):
         info(f'\twrite {path}')
         with open(path, mode) as out:
             out.write(content)
-        return open(path, mode).read() == content
+        return open(path, mode=mode.replace('w','r')).read() == content
 
     def send(self, local, remote):
         info(f'\tsend {local} -> {remote}')
